==> ejc-purchasingmanagement-api-3.0.0-20220520.062336-86-sources.jar: com/ejianc/business/purchasingmanagement/vo/WeighingInfoVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 称重信息
 * 
 * @author generator
 * 
 */
public class WeighingInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-mm-dd hh:mm:ss", timezone = "GMT+8")
    private Date weighingTime; // 称重时间
    private Long purchasereceiptId; // 收货单ID
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
        private Long firstTimeId; // 上次称重ID
    private Long orgId; // 所属组织id
    private BigDecimal  weight;//称重重量

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

}

==> ejc-purchasingmanagement-api-3.0.0-20220520.125116-88-sources.jar: com/ejianc/business/purchasingmanagement/vo/WeighingInfoVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 称重信息
 * 
 * @author generator
 * 
 */
public class WeighingInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-mm-dd hh:mm:ss", timezone = "GMT+8")
    private Date weighingTime; // 称重时间
    private Long purchasereceiptId; // 收货单ID
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    private Long firstTimeId; // 上次称重ID
    private Long orgId; // 所属组织id
    private BigDecimal  weight;//称重重量
    private Long materialplanId; // 定料计划ID
    private BigDecimal netWeight;  // 净重
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

}
